#delimit ;
set more off;

local derivedvarsdir "p:\elsa\archiving\derivedvars\final";
local textdir "P:\ELSA\ReportTables\Wave7\longitudinaltablesnewcohort\textfiles";
local FW = 4; /*first wave*/
local LW = 8; /*last wave*/
local BL = 4; /*baseline wave*/


tempfile ltablea ltableb ltablec ltabled ltablee ltablef ltableg ltableh ltablei;
/**use the life history data to fill in education for people who say still in ft ed**/

use "M:\ELSA\data\Wave_3_Life_History_Data.dta", clear;
keep idauniq rwagele;
sort idauniq;
save temped,replace;

use "M:\ELSA\data\Collaborators\Wave8\FinalMainStage\ELSAW8_Collaborators_Archive_2018_03_29.dta", clear;
keep idauniq w8w4lwgt;
save w8lwgt_w4,replace;


forval W = `FW'/`LW' {;
use `derivedvarsdir'\derivedvarsw`W',replace;
keep idauniq age sex ageg5 butype wpactive pp_* totwq5_bu_s yq5_bu_s wpactive
     empinc_bu_s seinc_bu_s ppinc_bu_s spinc_bu_s beninc_bu_s assinc_bu_s othinc_bu_s totinc_bu_s
     eqempinc_bu_s eqseinc_bu_s eqppinc_bu_s eqspinc_bu_s eqbeninc_bu_s eqassinc_bu_s eqothinc_bu_s eqtotinc_bu_s
     findiff ndepriv hlimwrk lwgt elsa ageg3 schleave intdaty spage cpiplus;



/*taken from this series
 https://www.ons.gov.uk/economy/inflationandpriceindices/adhocs/008572consumerpriceindicesseriesexcludingrentsmaintenancerepairsandwaterchargesfortheperiodjanuary1996toapril2018*/

gen cpiplusJan2011 = 91.5;
gen cpiplusJan2013 = 97.2;
gen cpiplusJan2015 = 99.3;
gen cpiplusJan2017 = 101.2;
replace cpiplus = cpiplus *(cpiplusJan2011/cpiplusJan2017);

/**base all monetary value in Jan prices**/
foreach V of varlist
empinc_bu_s seinc_bu_s ppinc_bu_s spinc_bu_s beninc_bu_s assinc_bu_s othinc_bu_s totinc_bu_s
eqempinc_bu_s eqseinc_bu_s eqppinc_bu_s eqspinc_bu_s eqbeninc_bu_s eqassinc_bu_s eqothinc_bu_s eqtotinc_bu_s {;
replace `V' = `V'/cpiplus;
};

gen earn_bu_s = empinc_bu_s+seinc_bu_s;
gen benpen_bu_s = spinc_bu_s+beninc_bu_s;
gen assoth_bu_s = assinc_bu_s+othinc_bu_s;
gen eqearn_bu_s = eqempinc_bu_s+eqseinc_bu_s;
gen eqbenpen_bu_s = eqspinc_bu_s+eqbeninc_bu_s;
gen eqassoth_bu_s = eqassinc_bu_s+eqothinc_bu_s;
gen depriv3 = ndepriv>=3;
replace depriv3 = ndepriv if ndepriv<0;
gen depriv1 = ndepriv>=1;
replace depriv1 = ndepriv if ndepriv<0;
gen workdis = hlimwrk==2;
replace workdis = hlimwrk if hlimwrk<0;
foreach V of varlist _all {;
rename `V' `V'_w`W';
};
rename idauniq_w`W' idauniq;
sort idauniq;
save temp`W',replace;
};

use temp`FW',replace;
forval W = `=`FW'+1'/`LW' {;
sort idauniq;
merge idauniq using temp`W';
tab _m;
keep if _m==3;
drop _m;
};

keep if elsa_w`BL'==1;

save temp,replace;

use temp,replace;

sort idauniq;
merge idauniq using temped;
drop if _m==2;
drop _m;

sort idauniq;
merge 1:1 idauniq using w8lwgt_w4;
assert _m~=1;
drop if _m==2;
drop _m;


/**generating baseline variables**/

gen age = age_w`BL';
gen ageg7 = ageg5_w`BL';
gen ageg3 = ageg3_w`BL';
gen schleave = schleave_w`BL';
replace ageg7 = 7 if ageg5_w`BL'==8;
gen sex = sex_w`BL';
gen butype = butype_w`BL';
gen butype2 = butype;
replace butype2 = 4 if butype==3 & sex==2;
gen wpactive = wpactive_w`BL';
gen pp_mem = pp_mem_w`BL';
gen totwq5_bu_s = totwq5_bu_s_w`BL';
gen yq5_bu_s = yq5_bu_s_w`BL';
gen totinc_bu_s = totinc_bu_s_w`BL';
gen eqtotinc_bu_s = eqtotinc_bu_s_w`BL';

gen ageg7_75 = ageg7;
replace ageg7_75 = 4 if ageg7==5;

gen ageg6 = ageg7;
replace ageg6 = 6 if ageg7==7;

gen ageced = rwagele;
replace ageced = . if rwagele<0;
gen dob = intdaty_w`BL'-age;
gen yrlefted     = dob + ageced;
gen schleave_r = 0 if (ageced <=14 & yrlefted < 1948)|(ageced <= 15 & yrlefted >= 1948 & yrlefted < 1973) | (ageced <= 16 & yrlefted >= 1973);  /*csl*/
replace schleave_r = 1 if ageced < 19 & schleave_r == .; /*alev*/
replace schleave_r = 2 if schleave_r==. & ageced ~= .;   /*coll*/
replace schleave_r = rwagele if rwagele<0;
drop ageced yrlefted;

replace schleave = schleave_r if schleave<0 & schleave_r>0 & schleave_r~=.;;

gen lwgt = w8w4lwgt;
drop if lwgt==.;
*gen lwgt = 1;

/*financial hardship**/

local NW = `LW'-`FW'+1;

/*financial difficulties**/
gen nobsf = 0;
forval i = `FW'/`LW' {;
replace nobsf = nobsf+1 if findiff_w`i'>=0;
};

egen fdiffcount = anycount(findiff_w*), v(4 5 6);
egen sevfdiffcount = anycount(findiff_w*), v(6);
egen mwellcount = anycount(findiff_w*), v(1);

gen fdiff_nev = fdiffcount==0 if nobsf>0;
gen fdiff_alw = fdiffcount==nobs if nobsf>0;
gen fdiff_som = fdiffcount>0 & fdiffcount<nobsf if nobsf>0;

gen sevfdiff_nev = sevfdiffcount==0 if nobsf>0;
gen sevfdiff_alw = sevfdiffcount==nobs if nobsf>0;
gen sevfdiff_som = sevfdiffcount>0 & fdiffcount<nobsf if nobsf>0;

gen mwell_nev = mwellcount==0 if nobsf>0;
gen mwell_alw = mwellcount==nobs if nobsf>0;
gen mwell_som = mwellcount>0 & mwellcount<nobsf if nobsf>0;

/**deprivation measure**/
gen nobsd = 0;
forval i = `FW'/`LW' {;
replace nobsd = nobsd+1 if depriv3_w`i'>=0;
};

egen depriv3count = anycount(depriv3_w*), v(1);
gen depriv3_nev = depriv3count==0 if nobsd>0;
gen depriv3_alw = depriv3count==nobsd if nobsd>0;
gen depriv3_som = depriv3count>0 & depriv3count<nobsd if nobsd>0;

replace nobsd = 0;
forval i = `FW'/`LW' {;
replace nobsd = nobsd+1 if depriv1_w`i'>=0;
};

egen depriv1count = anycount(depriv1_w*), v(1);
gen depriv1_nev = depriv1count==0 if nobsd>0;
gen depriv1_alw = depriv1count==nobsd if nobsd>0;
gen depriv1_som = depriv1count>0 & depriv1count<nobsd if nobsd>0;

/*pension contributions*/
gen nobsp = 0;
forval i = `FW'/`LW' {;
replace nobsp = nobsp+1 if pp_cont_w`i'>=0 & spage_w`i'==0;
};

gen fullemp = 1 if spage_w`BL'==0;
forval i = `FW'/`LW' {;
replace fullemp = 0 if wpactive_w`i'==0 & spage_w`i'==0;
};

egen pp_contcount = anycount(pp_cont_w*), v(1);
gen pp_cont_nev = pp_contcount==0 if nobsp>0;
gen pp_cont_alw = pp_contcount>=nobsp if nobsp>0;
gen pp_cont_som = pp_contcount>0 & pp_contcount<nobsp if nobsp>0;

/*work disability**/
gen nobsw = 0;
forval i = `FW'/`LW' {;
replace nobsw = nobsw+1 if workdis_w`i'>=0;
};

egen workdiscount = anycount(workdis_w*), v(1);
gen workdis_nev = workdiscount==0 if nobsw>0;
gen workdis_alw = workdiscount==nobsw if nobsw>0;
gen workdis_som = workdiscount>0 & workdiscount<nobsw if nobsw>0;

sort idauniq;
save y:\zoe\temp,replace;
preserve;
keep idauniq workdis_w*;
reshape long workdis_w, i(idauniq) j(wave);
drop if workdis<0;
sort idauniq wave;
bys idauniq: gen diff = workdis[_n]-workdis[_n-1];
egen nplus  = sum(diff==1),  by(idauniq);
egen nminus = sum(diff==-1), by(idauniq);
gen onset = nplus==1 & nminus==0;
gen transient = nminus>=1|nplus>1;
gen alwnev = nplus==0 & nminus==0;
assert onset+transient+alwnev==1;
keep idauniq onset transient alwnev;
bys idauniq: keep if _n==1;
sort idauniq;
save y:\zoe\workdis,replace;

restore;
merge idauniq using y:\zoe\workdis;
drop _m;

gen workdis_ons = onset;
gen workdis_tra = transient;

gen F = 1;

save longtemp,replace;

use longtemp,replace;

/**results***/

/***********************************************************************/
/** table 1 average income from each source by baseline age and hhtype */
/***********************************************************************/

foreach Y in earn ppinc benpen assoth totinc {;

local cmd "(mean) eq`Y'_bu_s_w4 eq`Y'_bu_s_w5 eq`Y'_bu_s_w6  eq`Y'_bu_s_w7  eq`Y'_bu_s_w8 (count) N = totinc_bu_s (rawsum) F if totinc_bu_s~=. [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(butype2 ageg7);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg7);
gen butype2 = 5;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(butype2);
gen ageg7 = 0;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd';
gen butype2 = 5;
gen ageg7  = 0;
save `ltabled',replace;
use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort butype ageg7;

qui do ../labels.do;
label values butype2 butype2;
label values ageg7 ageg7;

save ltable1_`Y', replace;
outsheet ageg7 butype2 eq`Y'_bu_s_w* using `textdir'\ltable1_`Y'.txt, replace;
outsheet ageg7 butype2 N F using `textdir'\ltable1_`Y'N.txt, replace;

};

/********************************************************************************/
/** table 2 average income from each source by baseline age and income education */
/********************************************************************************/

foreach Y in earn ppinc benpen assoth totinc {;

local cmd "(mean) eq`Y'_bu_s_w4 eq`Y'_bu_s_w5 eq`Y'_bu_s_w6 eq`Y'_bu_s_w7 eq`Y'_bu_s_w8 (count) N = totinc_bu_s (rawsum) F if totinc_bu_s~=. & schleave>=0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(schleave ageg6);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg6);
gen schleave = -1;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(schleave);
gen ageg6 = 0;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd';
gen schleave = -1;
gen ageg6  = 0;
save `ltabled',replace;
use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort ageg6 schleave;

qui do ../labels.do;
label values schleave ed;
label values ageg6 ageg6;

save ltable2_`Y', replace;
outsheet schleave ageg6 eq`Y'_bu_s_w* using `textdir'\ltable2_`Y'.txt, replace;
outsheet schleave ageg6 N F using `textdir'\ltable2_`Y'N.txt, replace;

};


/***********************************************************/
/** table 3 interquartile range by baseline age and hhtype */
/***********************************************************/
use longtemp,replace;

*local cmd "(iqr) eqtotinc_bu_s_w4 eqtotinc_bu_s_w5 eqtotinc_bu_s_w6 eqtotinc_bu_s_w7 eqtotinc_bu_s_w8 (count) N = totinc_bu_s (rawsum) F if totinc_bu_s~=. [pw = lwgt]";
local cmd "(p25) eqtotinc_bu_s_w4_p25 = eqtotinc_bu_s_w4 eqtotinc_bu_s_w5_p25 = eqtotinc_bu_s_w5 eqtotinc_bu_s_w6_p25 = eqtotinc_bu_s_w6
                 eqtotinc_bu_s_w7_p25 = eqtotinc_bu_s_w7 eqtotinc_bu_s_w8_p25 = eqtotinc_bu_s_w8
           (p75) eqtotinc_bu_s_w4_p75 = eqtotinc_bu_s_w4 eqtotinc_bu_s_w5_p75 = eqtotinc_bu_s_w5 eqtotinc_bu_s_w6_p75 = eqtotinc_bu_s_w6
                 eqtotinc_bu_s_w7_p75 = eqtotinc_bu_s_w7 eqtotinc_bu_s_w8_p75 = eqtotinc_bu_s_w8
           (count) N = totinc_bu_s (rawsum) F if totinc_bu_s~=. [pw = lwgt]";

collapse `cmd', by(butype2 ageg7);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg7);
gen butype2 = 5;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(butype2);
gen ageg7 = 0;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd';
gen butype2 = 5;
gen ageg7  = 0;
save `ltabled',replace;
use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort butype ageg7;

qui do ../labels.do;
label values butype2 butype2;
label values ageg7 ageg7;

save ltable3,replace;

forval i = `BL'/`LW' {;
gen eqtotinc_bu_s_w`i' = eqtotinc_bu_s_w`i'_p75/eqtotinc_bu_s_w`i'_p25;
drop eqtotinc_bu_s_w`i'_p25 eqtotinc_bu_s_w`i'_p75;
};
outsheet ageg7 butype2 eqtotinc_bu_s_w* using `textdir'\ltable3.txt, replace;
outsheet ageg7 butype2 N F using `textdir'\ltable3N.txt, replace;

/**************************************************************/
/***Table 4 - persistence of private pension contribution ****/
/**************************************************************/

/*a - all*/

local cmd "(mean) pp_cont_nev pp_cont_som pp_cont_alw (count) N = wpactive (rawsum) F if totwq5_bu_s~=. & wpactive_w`BL'==1  & age<75 & nobsp>0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex totwq5_bu_s);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen totwq5_bu_s = 0;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 totwq5_bu_s);
gen sex = 3;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd', by(sex totwq5_bu_s);
gen ageg7_75 = 0;
save `ltabled', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen totwq5_bu_s = 0;
save `ltablee', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen totwq5_bu_s = 0;
gen ageg7_75  = 0;
save `ltablef', replace;
use longtemp,replace;
collapse `cmd', by(totwq5_bu_s);
gen sex = 3;
gen ageg7_75 = 0;
save `ltableg', replace;
use longtemp,replace;
collapse `cmd';
gen sex = 3;
gen ageg7_75 = 0;
gen totwq5_bu_s = 0;
save `ltableh', replace;

use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};

sort sex ageg7_75 totwq5_bu_s;

qui do ../labels.do;
label values totwq5_bu_s wealthq;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable4a,replace;
outsheet sex totwq5_bu_s ageg7_75 pp_cont_nev pp_cont_som pp_cont_alw N F using `textdir'\ltable4.txt, replace;

/*b - employed all waves below SPA */

local cmd "(mean) pp_cont_nev pp_cont_som pp_cont_alw (count) N = wpactive (rawsum) F if totwq5_bu_s~=. & fullemp==1  & age<75 & nobsp>0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex totwq5_bu_s);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen totwq5_bu_s = 0;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 totwq5_bu_s);
gen sex = 3;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd', by(sex totwq5_bu_s);
gen ageg7_75 = 0;
save `ltabled', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen totwq5_bu_s = 0;
save `ltablee', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen totwq5_bu_s = 0;
gen ageg7_75  = 0;
save `ltablef', replace;
use longtemp,replace;
collapse `cmd', by(totwq5_bu_s);
gen sex = 3;
gen ageg7_75 = 0;
save `ltableg', replace;
use longtemp,replace;
collapse `cmd';
gen sex = 3;
gen ageg7_75 = 0;
gen totwq5_bu_s = 0;
save `ltableh', replace;

use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};

sort sex ageg7_75 totwq5_bu_s;

qui do ../labels.do;
label values totwq5_bu_s wealthq;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable4b,replace;
outsheet sex totwq5_bu_s ageg7_75 pp_cont_nev pp_cont_som pp_cont_alw N F using `textdir'\ltable4b.txt, replace;

/************************************************************************************/
/* Table 5 cross-wave prevalence of financial difficulties, by age and family type  */
/************************************************************************************/

/*any diff*/
local cmd "(mean) fdiff_nev fdiff_som fdiff_alw (count) N = nobsf (rawsum) F if nobsf>0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(butype ageg7);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg7);
gen butype = 4;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(butype);
gen ageg7 = 0;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd';
gen butype = 4;
gen ageg7  = 0;
save `ltabled',replace;
use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort butype ageg7;

qui do ../labels.do;
label values butype butypetab;
label values ageg7 ageg7;

save ltable5a, replace;
outsheet ageg7 butype fdiff_nev fdiff_som fdiff_alw N F using `textdir'\ltable5a.txt, replace;

/*manage well*/

local cmd "(mean) mwell_alw mwell_som mwell_nev (count) N = nobsf (rawsum) F if nobsf>0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(butype ageg7);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg7);
gen butype = 4;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(butype);
gen ageg7 = 0;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd';
gen butype = 4;
gen ageg7  = 0;
save `ltabled',replace;
use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort butype ageg7;

qui do ../labels.do;
label values butype butypetab;
label values ageg7 ageg7;

save ltable5b, replace;
outsheet ageg7 butype mwell_alw mwell_som mwell_nev N F using `textdir'\ltable5b.txt, replace;

/**************************************************************************************************/
/* Table 5c cross-wave prevalence of financial difficulties, by age and family type and education  */
/**************************************************************************************************/

/*any diff*/
local cmd "(mean) fdiff_nev fdiff_som fdiff_alw (count) N = nobsf (rawsum) F if nobsf>0  & schleave>=0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg3 butype schleave);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg3 butype);
gen schleave = -1;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(ageg3 schleave);
gen butype = 4;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd', by(butype schleave);
gen ageg3 = 0;
save `ltabled',replace;
use longtemp,replace;
collapse `cmd', by(ageg3);
gen butype = 4;
gen schleave = -1;
save `ltablee',replace;
use longtemp,replace;
collapse `cmd', by(butype);
gen ageg3 = 0;
gen schleave = -1;
save `ltablef',replace;
use longtemp,replace;
collapse `cmd', by(schleave);
gen ageg3 = 0;
gen butype = 4;
save `ltableg',replace;
use longtemp,replace;
collapse `cmd';
gen schleave = -1;
gen ageg3  = 0;
gen butype = 4;
save `ltableh',replace;
use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};
sort ageg3 butype schleave;

qui do ../labels.do;
label values butype butypetab;
label values ageg3 ageg3;
label values schleave ed;

save ltable5c, replace;
*outsheet ageg3 schleave butype fdiff_nev fdiff_som fdiff_alw N F using `textdir'\ltable5c.txt, replace;

/*manage well*/

local cmd "(mean) mwell_alw mwell_som mwell_nev (count) N = nobsf (rawsum) F if nobsf>0  & schleave>=0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg3 butype schleave);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg3 butype);
gen schleave = -1;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(ageg3 schleave);
gen butype = 4;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd', by(butype schleave);
gen ageg3 = 0;
save `ltabled',replace;
use longtemp,replace;
collapse `cmd', by(ageg3);
gen butype = 4;
gen schleave = -1;
save `ltablee',replace;
use longtemp,replace;
collapse `cmd', by(butype);
gen ageg3 = 0;
gen schleave = -1;
save `ltablef',replace;
use longtemp,replace;
collapse `cmd', by(schleave);
gen ageg3 = 0;
gen butype = 4;
save `ltableg',replace;
use longtemp,replace;
collapse `cmd';
gen schleave = -1;
gen ageg3  = 0;
gen butype = 4;
save `ltableh',replace;
use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};
sort ageg3 butype schleave;

qui do ../labels.do;
label values butype butypetab;
label values ageg3 ageg3;
label values schleave ed;

save ltable5c, replace;
*outsheet ageg3 schleave butype mwell_alw mwell_som mwell_nev N F using `textdir'\ltable5c.txt, replace;

/***************************************************************************************/
/* Table 6 cross-wave prevalence of deprivation, by age and family type and education  */
/***************************************************************************************/

local cmd "(mean) depriv3_nev depriv3_som depriv3_alw (count) N = nobsd (rawsum) F if nobsd>0  & schleave>=0 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg3 butype2 schleave);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg3 butype2);
gen schleave = -1;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(ageg3 schleave);
gen butype2 = 5;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd', by(butype2 schleave);
gen ageg3 = 0;
save `ltabled',replace;
use longtemp,replace;
collapse `cmd', by(ageg3);
gen butype2 = 5;
gen schleave = -1;
save `ltablee',replace;
use longtemp,replace;
collapse `cmd', by(butype2);
gen ageg3 = 0;
gen schleave = -1;
save `ltablef',replace;
use longtemp,replace;
collapse `cmd', by(schleave);
gen ageg3 = 0;
gen butype2 = 5;
save `ltableg',replace;
use longtemp,replace;
collapse `cmd';
gen schleave = -1;
gen ageg3  = 0;
gen butype2 = 5;
save `ltableh',replace;
use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};
sort ageg3 butype2 schleave;

qui do ../labels.do;
label values butype2 butype2;
label values ageg3 ageg3;
label values schleave ed;

save ltable6, replace;
outsheet ageg3 schleave butype2 depriv3_nev depriv3_som depriv3_alw N F using `textdir'\ltable6.txt, replace;

/******************************************************************************************************/
/**Table 7 - proportion still in employment by baseline  age, sex, wealth. working at baseline**/
/******************************************************************************************************/

/*part a - % working at baseline**/
local cmd "(mean) wpactive_w`BL' if totwq5_bu_s~=. & age<75 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex totwq5_bu_s);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen totwq5_bu_s = 0;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 totwq5_bu_s);
gen sex = 3;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd', by(sex totwq5_bu_s);
gen ageg7_75 = 0;
save `ltabled', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen totwq5_bu_s = 0;
save `ltablee', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen totwq5_bu_s = 0;
gen ageg7_75  = 0;
save `ltablef', replace;
use longtemp,replace;
collapse `cmd', by(totwq5_bu_s);
gen sex = 3;
gen ageg7_75 = 0;
save `ltableg', replace;
use longtemp,replace;
collapse `cmd';
gen sex = 3;
gen ageg7_75 = 0;
gen totwq5_bu_s = 0;
save `ltableh', replace;

use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};
sort sex ageg7_75 totwq5_bu_s;

qui do ../labels.do;
label values totwq5_bu_s wealthq;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable7a,replace;
outsheet using `textdir'\ltable7a.txt, replace;

/*part b - % working at subsequent waves - workers only**/

local cmd "(mean) wpactive_w4 wpactive_w5 wpactive_w6 wpactive_w7 wpactive_w8 (count) N = wpactive (rawsum) F if totwq5_bu_s~=. & wpactive_w`BL'==1  & age<75 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex totwq5_bu_s);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen totwq5_bu_s = 0;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 totwq5_bu_s);
gen sex = 3;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd', by(sex totwq5_bu_s);
gen ageg7_75 = 0;
save `ltabled', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen totwq5_bu_s = 0;
save `ltablee', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen totwq5_bu_s = 0;
gen ageg7_75  = 0;
save `ltablef', replace;
use longtemp,replace;
collapse `cmd', by(totwq5_bu_s);
gen sex = 3;
gen ageg7_75 = 0;
save `ltableg', replace;
use longtemp,replace;
collapse `cmd';
gen sex = 3;
gen ageg7_75 = 0;
gen totwq5_bu_s = 0;
save `ltableh', replace;

use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};

sort sex ageg7_75 totwq5_bu_s;

qui do ../labels.do;
label values totwq5_bu_s wealthq;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable7b,replace;
outsheet sex totwq5_bu_s ageg7_75 wpactive* using `textdir'\ltable7b.txt, replace;
outsheet sex totwq5_bu_s ageg7_75 N F using `textdir'\ltable7bN.txt, replace;

/******************************************************************************************************/
/**Table 8 - proportion still in employment by baseline  age, sex, pension status working at baseline**/
/******************************************************************************************************/

/*% working at baseline - workers only**/

local cmd "(mean) wpactive_w`BL' (count) N = wpactive (rawsum) F if totwq5_bu_s~=. & age<75 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex pp_mem);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen pp_mem = -1;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 pp_mem);
gen sex = 3;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd', by(sex pp_mem);
gen ageg7_75 = 0;
save `ltabled', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen pp_mem = -1;
save `ltablee', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen pp_mem = -1;
gen ageg7_75  = 0;
save `ltablef', replace;
use longtemp,replace;
collapse `cmd', by(pp_mem);
gen sex = 3;
gen ageg7_75 = 0;
save `ltableg', replace;
use longtemp,replace;
collapse `cmd';
gen sex = 3;
gen ageg7_75 = 0;
gen pp_mem = -1;
save `ltableh', replace;

use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};
sort sex age pp_mem;


qui do ../labels.do;
label values pp_mem ppmemtab;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable8a,replace;
outsheet using `textdir'\ltable8a.txt, replace;

/*% working at subsequent waves - workers only**/

local cmd "(mean) wpactive_w4 wpactive_w5 wpactive_w6 wpactive_w7 wpactive_w8 (count) N = wpactive (rawsum) F if totwq5_bu_s~=. & wpactive_w`BL'==1 & age<75  [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex pp_mem);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen pp_mem = -1;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 pp_mem);
gen sex = 3;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd', by(sex pp_mem);
gen ageg7_75 = 0;
save `ltabled', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen pp_mem = -1;
save `ltablee', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen pp_mem = -1;
gen ageg7_75  = 0;
save `ltablef', replace;
use longtemp,replace;
collapse `cmd', by(pp_mem);
gen sex = 3;
gen ageg7_75 = 0;
save `ltableg', replace;
use longtemp,replace;
collapse `cmd';
gen sex = 3;
gen ageg7_75 = 0;
gen pp_mem = -1;
save `ltableh', replace;

use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};

sort sex age pp_mem;

qui do ../labels.do;
label values pp_mem ppmemtab;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable8b,replace;
outsheet sex pp_mem ageg7_75 wpactive* using `textdir'\ltable8b.txt, replace;
outsheet sex pp_mem ageg7_75 N F using `textdir'\ltable8bN.txt, replace;

/******************************************************************************************************/
/**Table 8 - proportion in employment by baseline  age, sex. NOT working at baseline**/
/******************************************************************************************************/

/*part a - % working at baseline**/
local cmd "(mean) wpactive_w`BL' if totwq5_bu_s~=. & age<75 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen ageg7_75 = 0;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd';
gen ageg7_75 = 0;
gen sex = 3;
save `ltabled', replace;

use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort sex ageg7_75;

qui do ../labels.do;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable8,replace;
outsheet using `textdir'\ltable8a.txt, replace;

local cmd "(mean) wpactive_w4 wpactive_w5 wpactive_w6 wpactive_w7 wpactive_w8 (count)N = wpactive (rawsum) F if totwq5_bu_s~=. & wpactive_w`BL'==0 & age<75  [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
save `ltablea', replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
save `ltableb', replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen ageg7_75 = 0;
save `ltablec', replace;
use longtemp,replace;
collapse `cmd';
gen ageg7_75 = 0;
gen sex = 3;
save `ltabled', replace;

use `ltablea',replace;
foreach V in b c d {;
append using `ltable`V'';
};
sort sex ageg7_75;

qui do ../labels.do;
label values ageg7_75 ageg7_75;
label values sex sextab;

save ltable8,replace;
outsheet sex ageg7_75 wpactive* using `textdir'\ltable8b.txt, replace;
outsheet sex ageg7_75 N F using `textdir'\ltable8bN.txt, replace;


/**************************************************************************************/
/* Table 9 cross-wave prevalence of work disability, by age and sex and work status  */
/**************************************************************************************/

local cmd "(mean) workdis_nev workdis_tra workdis_ons workdis_alw (count) N = nobsw (rawsum) F if nobsw>0 & totwq5_bu_s~=. & age<75 [pw = lwgt]";

use longtemp,replace;
collapse `cmd', by(ageg7_75 sex totwq5_bu_s);
save `ltablea',replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 sex);
gen totwq5_bu_s = 0;
save `ltableb',replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75 totwq5_bu_s);
gen sex = 3;
save `ltablec',replace;
use longtemp,replace;
collapse `cmd', by(sex totwq5_bu_s);
gen ageg7_75 = 0;
save `ltabled',replace;
use longtemp,replace;
collapse `cmd', by(ageg7_75);
gen sex = 3;
gen totwq5_bu_s = 0;
save `ltablee',replace;
use longtemp,replace;
collapse `cmd', by(sex);
gen ageg7_75 = 0;
gen totwq5_bu_s = 0;
save `ltablef',replace;
use longtemp,replace;
collapse `cmd', by(totwq5_bu_s);
gen ageg7_75 = 0;
gen sex = 3;
save `ltableg',replace;
use longtemp,replace;
collapse `cmd';
gen totwq5_bu_s = 0;
gen ageg7_75  = 0;
gen sex = 3;
save `ltableh',replace;
use `ltablea',replace;
foreach V in b c d e f g h {;
append using `ltable`V'';
};
sort ageg7_75 sex totwq5_bu_s;

qui do ../labels.do;
label values sex sextab;
label values ageg7_75 ageg7_75;
label values totwq5_bu_s wealthq;

save ltable9, replace;
outsheet ageg7_75 totwq5_bu_s sex workdis_nev workdis_tra workdis_ons workdis_alw N F using `textdir'\ltable9.txt, replace;
